
# Overview

This package is aimed to be used for the Continuous Integration of Exasol's ScriptLanguage Container.
It implements the steps which are executed when pushing to specific branches of a ScriptLanguage Container repository (for example https://github.com/exasol/script-languages).

